@@ -13,6 +13,7 @@ def _seemsValidRawArticle(soup, text_limit = 500):
 
 def _getInnerArticle_(soup, domain):	
 	applicators = [
+		lambda x: x.find("article"),
 		lambda x: x.find("article"),
 		lambda x: x.find("div", {"id" : "js_content"}),
 		lambda x: x.find("div", class_ = "story-body__inner"),
@@ -27,6 +28,7 @@ def _getInnerArticle_(soup, domain):
 		lambda x: x.find("div", class_ = "u-content"),
 		lambda x: x.find("div", class_ = "RichContent-inner"),
 		lambda x: x.find("div", class_ = "entry-content"),
+		lambda x: x.find("main", class_ = 'main-content'),
 	]
 	domain_specific_applicators = {
 		'': [lambda x: x.find("body")],
@@ -36,8 +38,11 @@ def _getInnerArticle_(soup, domain):
 			lambda x: x.find("div", class_ = "note"),
 			lambda x: x.find("div", class_ = "review-content"),
 			lambda x: x.find("div", class_ = "status-wrapper"),],
-		'thepaper': [lambda x: x.find("div", class_ = "news_txt")],
+		'thepaper': [
+			lambda x: x.find("div", class_ = "news_txt"),
+			lambda x: x.find('div', class_ = 'news_part')],
 		'gravitysworm': [lambda x: x.find("div", class_ = "copy")],
+		'opinion.cw.com.tw': [lambda x: x.find("article"),],
 	}
 	is_short = matchKey(soup.text, SHORT_ARTICLE)
 	text_limit = 150 if is_short else 500
