@@ -10,13 +10,13 @@ import sys
 OFFTOPIC_TAG = ['small', 'address', 'meta', 'script', 'sup']
 
 OFFTOPIC_ATT = [
-	'comment', 'latest', 'more', 'button', 'facebook', 
+	'latest', 'more', 'button', 'facebook',
 	'cn-carousel-medium-strip', 'video__end-slate__top-wrapper', 'metadata', 
 	'el__article--embed', 'signup', 'related', 'disclaimer', 'off-screen', 
 	'story-body__unordered-list', 'story-image-copyright', 'article-header', 
 	'top-wrapper', 'bottom-of-article', 'bottom-wrapper', 'linkList', 
 	'display:none;', 'accordion', 'el-editorial-source', 'video__end-slate__tertiary-title',
-	'adblocker', 'tagline', 'navbar', 'navmenu', 'topHeader', 'Post Bottom',
+	'adblocker', 'tagline', 'navmenu', 'topHeader', 'Post Bottom',
 	't_callout', 'add-interest', 'bb-newsletter', 'popover', 'toast', 'after-article', 
 	'submeta', 'rich-link__container', 'content__meta-container', 'mw-editsection',
 	'noprint', 'jump-to-nav', 'toctitle', 'reflist', 'contentSub',
@@ -24,7 +24,9 @@ OFFTOPIC_ATT = [
 	'ad-unit', 'box-ad', "class : ['tabs']", "class : ['hd']", 'NYT_BELOW_MAIN_CONTENT_REGION',
 	'NYT_TOP_BANNER_REGION', 'g-inlineguide', 'entry-meta-bar', 'extra-hatom-entry-title',
 	'list-unstyled', 'hide_word', 'single-header', 'post-pagination',
-	'weui-dialog', 'post-title', 'post-topic', 'byline-date'
+	'weui-dialog', 'post-title', 'post-topic', 'byline-date', 'post-print',
+	'mailing-list-popup', 'taxonomies', 'authors', 'interactive-content',
+	'socialBTN', 'page-view',
 ]
 
 OFFTOPIC_ATT_WITH_EXCEPTION = {
@@ -32,19 +34,22 @@ OFFTOPIC_ATT_WITH_EXCEPTION = {
 	'hidden': ['lazy', 'false', 'label-hidden', 'rich_media_content', 'start', 'overflow'],
 	'navigation': ['navigation-border-thin-decoration'],
 	'copyright': ['and'],
+	'navbar': ['single-post']
 }
 
 OFFTOPIC_CLASSES = ['ads']
 
 DIV_AD_WORDS = [
 	'中文简报',
-	'@nytimes'
+	'@nytimes',
+	'NYT简报',
 ]
 
 P_AD_WORDS = [
 	'The Times is committed', 
 	'Follow The New York Times',
 	'Love HuffPost',
+	'discounted subscription today'
 ]
 
 def _isOffTopic(attrs):
@@ -82,7 +87,7 @@ def _decompseAds(soup):
 			_decompose(item)
 
 def _decomposeOfftopic(soup, url, args = {}):
-	for item in soup.find_all():
+	for item in list(soup.find_all())[1:]:
 		if _isOffTopic(item.attrs) or \
 			item.name in OFFTOPIC_TAG:
 			_decompose(item)
